`vesper_nighthawk` is a Python package that allows use of the
[Nighthawk](https://github.com/bmvandoren/Nighthawk) NFC detector
with [Vesper](https://github.com/HaroldMills/Vesper).

Please see the [Vesper documentation](https://vesper.readthedocs.io/en/latest/installation.html#installing-nighthawk-optional)
for installation instructions.

